@@ -27,16 +27,16 @@ def _guess_thing(f):
 @_guess_thing
 def format(thing=None, **kwargs):
     """
-    Render a call stack or the traceback of an exception.
+    Render the traceback of an exception or a frame's call stack
 
 
-    Call this with no argument inside an `except` block to get a traceback for
+    Call this without arguments inside an `except` block to get a traceback for
     the currently handled exception:
         ```
         try:
             something()
         except:
-            traceback_message = stackprinter.format(**kwargs)
+            logger.err(stackprinter.format(**kwargs))
         ```
 
     Explicitely pass an exception (or a triple as returned by `sys.exc_info()`)
@@ -48,31 +48,20 @@ def format(thing=None, **kwargs):
             last_exc = e
 
         if last_exc:
-            traceback_message = stackprinter.format(last_exc, **kwargs)
+            logger.err(stackprinter.format(last_exc, **kwargs))
         ```
 
     Pass a frame object to see the call stack leading up to that frame:
         ```
-        stack = stackprinter.format(sys._getframe(0), **kwargs))
-        ```
-
-    Two other ways to see the current call stack:
-        ```
-        # this works anywhere outside exception handling blocks:
-        stack = stackprinter.format(**kwargs)
-
-        # (this works anywhere:)
-        stack = stackprinter.format_current_stack(**kwargs)
+        stack = stackprinter.format(sys._getframe(2), **kwargs))
         ```
 
     Pass a thread object to see its current call stack:
         ```
         thread = threading.Thread(target=something)
         thread.start()
-        while True:
-            msg = stackprinter.format(thread, **kwargs))
-            print(msg)
-            time.sleep(0.1)
+        # (...)
+        stack = stackprinter.format(thread, **kwargs))
         ```
 
     Note:
@@ -86,35 +75,37 @@ def format(thing=None, **kwargs):
 
     Params
     ---
-    thing: (optional) exception, sys.exc_info() tuple, frame or thread object
+    thing: (optional) exception, sys.exc_info() tuple, frame or thread
         What to format. Defaults to the currently handled exception or current
         stack frame.
 
-    style: string 'color' or 'plaintext' (default: 'plaintext')
-        'color': Insert ANSI colored semantic highlights, for use in terminals
-                 that support 256 colors (or with something like the `ansi2html`
-                 package, to create colorful log files). There is only one color
-                 scheme and it assumes a dark background.
-        'plaintext': Just text.
+    style: string
+        'plaintext' (default): Output just text
 
-    source_lines: int or 'all'. (default: 5 lines)
+        'color', 'darkbg', 'lightbg', 'darkbg2', 'lightbg2':
+            Output ANSI-colors, for use with terminals that support 256
+            colors, notebooks or something like the `ansi2html` package,
+            to create colorful log files.
+
+    source_lines: int or 'all'
         Select how much source code context will be shown.
         int 0: Don't include a source listing.
-        int n > 0: Show n lines of code.
+        int n > 0: Show n lines of code. (default: 5)
         string 'all': Show the whole scope of the frame.
 
     show_signature: bool (default True)
         Always include the function header in the source code listing.
 
-    show_vals: str or None (default 'like_source')
+    show_vals: str or None
         Select which variable values will be shown.
         'line': Show only the variables on the highlighted line.
-        'like_source': Show those visible in the source listing (default).
+        'like_source' (default): Show only those visible in the source listing
         'all': Show every variable in the scope of the frame.
         None: Don't show any variable values.
 
-    truncate_vals: int (default 500)
-        Maximum number of characters to be used for each variable value
+    truncate_vals: int
+        Maximum number of characters to be used for each variable value.
+        Default: 500
 
     suppressed_paths: list of regex patterns
         Set less verbose formatting for frames whose code lives in certain paths
@@ -127,13 +118,13 @@ def format(thing=None, **kwargs):
         Example: To hide numpy internals from the traceback, set
         `suppressed_paths=[r"lib/python.*/site-packages/numpy"]`
 
-    reverse: bool (default False)
-        List the innermost frame first
+    reverse: bool
+        List the innermost frame first.
 
-    add_summary: True, False, 'auto'  (default: 'auto')
-        Append a short list of all involved paths and source lines, similar
-        to the built-in traceback message. On auto, do that if the main
-        traceback is longer than 50 lines.
+    add_summary: True, False, 'auto'
+        Append a compact list of involved files and source lines, similar
+        to the built-in traceback message.
+        'auto' (default): do that if the main traceback is longer than 50 lines.
 
     """
     if isinstance(thing, types.FrameType):
@@ -154,21 +145,43 @@ def format(thing=None, **kwargs):
 @_guess_thing
 def show(thing=None, file=sys.stderr, **kwargs):
     """
-    Print a stack trace or the traceback message for an exception.
+    Print the traceback of an exception or a frame's call stack
 
-    See `format` for full docs. This function is identical to `format` except
-    that it directly prints the result to `file`, defaulting to sys.stderr
+    Params
+    ---
+    file: 'stderr', 'stdout' or file-like object
+        defaults to stderr
+
+    **kwargs:
+        See `format`
     """
+    if file == 'stderr':
+        file = sys.stderr
+    elif file == 'stdout':
+        file = sys.stdout
+
     print(format(thing, **kwargs), file=file)
 
 
 
 def format_current_stack(**kwargs):
-    """ Render the current thread's call stack. Arguments like format() """
+    """ Render the current thread's call stack.
+
+    Params
+    --
+    **kwargs:
+        See `format`
+    """
     return format(sys._getframe(1), **kwargs)
 
 def show_current_stack(**kwargs):
-    """ Print the current thread's call stack. Arguments like show() """
+    """ Print the current thread's call stack.
+
+    Params
+    --
+    **kwargs:
+        See `show`
+    """
     show(sys._getframe(1), **kwargs)
 
 
@@ -178,7 +191,10 @@ def format_current_exception(**kwargs):
     """
     Render a traceback for the currently handled exception.
 
-    kwargs like format()
+    Params
+    --
+    **kwargs:
+        See `format`
     """
     return format(sys.exc_info(), **kwargs)
 
@@ -186,7 +202,10 @@ def show_current_exception(file=sys.stderr, **kwargs):
     """
     Print a traceback for the currently handled exception.
 
-    kwargs like show()
+    Params
+    --
+    **kwargs:
+        See `show`
     """
     print(format_current_exception(**kwargs), file=file)
 
@@ -196,28 +215,93 @@ def set_excepthook(**kwargs):
     """
     Set sys.excepthook to print a detailed traceback for any uncaught exception.
 
-    This doesn't work in IPython, since Ipython handles exceptions internally
-    i.e. the interpreter never sees an uncaught exception (and Ipython resets
-    the excepthook for its own purposes, anyway).
+    Examples:
 
-    kwargs like show()
+    ```
+    set_excepthook(file='stdout')    # print to stdout instead of stderr
+
+    ```
+
+    ```
+    set_excepthook(style=color)  # do ansi colors
+    ```
+
+    If running under Ipython, this will, with a heavy heart, attempt to monkey
+    patch Ipython's traceback printer (which handles all exceptions internally,
+    thus bypassing the system excepthook). You can decide whether this sounds
+    like a sane idea.
+
+    To undo, call `remove_excepthook`.
+
+    Params
+    --
+    **kwargs:
+        See `show`
     """
     if _is_running_in_ipython():
-        warnings.warn("Excepthooks have no effect when running under Ipython - "
-                      "capture exceptions manually to print tracebacks for them.",
-                      stacklevel=2)
-        return
+        _patch_ipython_excepthook(**kwargs)
     else:
         def hook(*args):
             show(args, **kwargs)
 
         sys.excepthook = hook
 
-def remove_exceptook():
+
+def remove_excepthook():
     """ Reinstate the default excepthook """
+    if _is_running_in_ipython():
+        _unpatch_ipython_excepthook()
     sys.excepthook = sys.__excepthook__
 
 
+def _is_running_in_ipython():
+    try:
+        return __IPYTHON__
+    except NameError:
+        return False
+
+
+ipy_tb = None
+
+def _patch_ipython_excepthook(**kwargs):
+    """ Replace ipython's built-in traceback printer, excellent though it is"""
+    global ipy_tb
+
+    blacklist = kwargs.get('suppressed_paths', [])
+    blacklist.append('site-packages/IPython/')
+    kwargs['suppressed_paths'] = blacklist
+
+    if 'file' in kwargs:
+        del kwargs['file']
+
+    def format_tb(*exc_tuple, **__):
+        unstructured_tb = format(exc_tuple, **kwargs)
+        structured_tb = [unstructured_tb]  # \*coughs*
+        return structured_tb
+
+    import IPython
+    shell = IPython.get_ipython()
+    if ipy_tb is None:
+        ipy_tb = shell.InteractiveTB.structured_traceback
+    shell.InteractiveTB.structured_traceback = format_tb
+
+
+def _unpatch_ipython_excepthook():
+    """ restore proper order in Ipython """
+    import IPython
+    shell = IPython.get_ipython()
+    if ipy_tb is not None:
+        shell.InteractiveTB.structured_traceback = ipy_tb
+
+
+def _is_exc_info(thing):
+    if not isinstance(thing, tuple) or len(thing) != 3:
+        return False
+    a, b, c = thing
+    return (isinstance(a, type) and BaseException in a.mro() and
+            isinstance(b, BaseException) and
+            isinstance(c, types.TracebackType))
+
 
 def format_thread(thread, add_summary=False, **kwargs):
     try:
@@ -232,22 +316,3 @@ def format_thread(thread, add_summary=False, **kwargs):
         msg = fmt.format_stack_from_frame(fr, **kwargs)
         msg_indented = '    ' + '\n    '.join(msg.split('\n')).strip()
         return "%r\n\n%s" % (thread, msg_indented)
-
-
-def _is_exc_info(thing):
-    if not isinstance(thing, tuple) or len(thing) != 3:
-        return False
-    a, b, c = thing
-    return (isinstance(a, type) and BaseException in a.mro() and
-            isinstance(b, BaseException) and
-            isinstance(c, types.TracebackType))
-
-
-def _is_running_in_ipython():
-    fr = sys._getframe(1)
-    while fr.f_back:
-        if fr.f_code.co_name == 'start_ipython':
-            return True
-        fr = fr.f_back
-    return False
-
